@@ -38,14 +38,17 @@
 // ----------------------------------------------------------------
 static mapper_setup_t* mapper_lookup_table[] = {
 
+	&mapper_altkv_setup,
 	&mapper_bar_setup,
 	&mapper_bootstrap_setup,
 	&mapper_cat_setup,
 	&mapper_check_setup,
+	&mapper_clean_whitespace_setup,
 	&mapper_count_distinct_setup,
 	&mapper_count_similar_setup,
 	&mapper_cut_setup,
 	&mapper_decimate_setup,
+	&mapper_fill_down_setup,
 	&mapper_filter_setup,
 	&mapper_fraction_setup,
 	&mapper_grep_setup,
