@@ -454,6 +454,13 @@ void lrec_dump_titled(char* msg, lrec_t* prec) {
 	printf("\n");
 }
 
+void lrec_pointer_dump(lrec_t* prec) {
+	printf("prec %p\n", prec);
+	for (lrece_t* pe = prec->phead; pe != NULL; pe = pe->pnext) {
+		printf("  pe %p k %p v %p\n", pe, pe->key, pe->value);
+	}
+}
+
 // ----------------------------------------------------------------
 static void lrec_unbacked_free(lrec_t* prec) {
 }
@@ -470,32 +477,6 @@ static void lrec_free_multiline_backing(lrec_t* prec) {
 	slls_free(prec->pxtab_lines);
 }
 
-// ----------------------------------------------------------------
-static char* static_nidx_keys[] = {
-	"0",   "1",  "2",  "3",  "4",  "5",  "6",  "7",  "8",  "9",
-	"10", "11", "12", "13", "14", "15", "16", "17", "18", "19",
-	"20", "21", "22", "23", "24", "25", "26", "27", "28", "29",
-	"30", "31", "32", "33", "34", "35", "36", "37", "38", "39",
-	"40", "41", "42", "43", "44", "45", "46", "47", "48", "49",
-	"50", "51", "52", "53", "54", "55", "56", "57", "58", "59",
-	"60", "61", "62", "63", "64", "65", "66", "67", "68", "69",
-	"70", "71", "72", "73", "74", "75", "76", "77", "78", "79",
-	"80", "81", "82", "83", "84", "85", "86", "87", "88", "89",
-	"90", "91", "92", "93", "94", "95", "96", "97", "98", "99", "100"
-};
-
-char* make_nidx_key(int idx, char* pfree_flags) {
-	if ((0 <= idx) && (idx <= 100)) {
-		*pfree_flags = 0;
-		return static_nidx_keys[idx];
-	} else {
-		char buf[32];
-		sprintf(buf, "%d", idx);
-		*pfree_flags = FREE_ENTRY_KEY;
-		return mlr_strdup_or_die(buf);
-	}
-}
-
 // ================================================================
 
 // ----------------------------------------------------------------
