@@ -231,13 +231,21 @@ static function_lookup_t FUNCTION_LOOKUP_TABLE[] = {
 
 	{FUNC_CLASS_STRING, ".",        2,0, "String concatenation."},
 	{FUNC_CLASS_STRING, "gsub",     3,0, "Example: '$name=gsub($name, \"old\", \"new\")'\n(replace all)."},
+	{FUNC_CLASS_STRING, "regextract", 2,0, "Example: '$name=regextract($name, \"[A-Z]{3}[0-9]{2}\")'\n."},
+	{FUNC_CLASS_STRING, "regextract_or_else", 3,0, "Example: '$name=regextract_or_else($name, \"[A-Z]{3}[0-9]{2}\", \"default\")'\n."},
 	{FUNC_CLASS_STRING, "strlen",   1,0, "String length."},
 	{FUNC_CLASS_STRING, "sub",      3,0, "Example: '$name=sub($name, \"old\", \"new\")'\n(replace once)."},
+	{FUNC_CLASS_STRING, "ssub",     3,0, "Like sub but does no regexing. No characters are special."},
 	{FUNC_CLASS_STRING, "substr",   3,0,
 		"substr(s,m,n) gives substring of s from 0-up position m to n \n"
 		"inclusive. Negative indices -len .. -1 alias to 0 .. len-1."},
 	{FUNC_CLASS_STRING, "tolower",  1,0, "Convert string to lowercase."},
 	{FUNC_CLASS_STRING, "toupper",  1,0, "Convert string to uppercase."},
+	{FUNC_CLASS_STRING, "lstrip",  1,0,  "Strip leading whitespace from string."},
+	{FUNC_CLASS_STRING, "rstrip",  1,0,  "Strip trailing whitespace from string."},
+	{FUNC_CLASS_STRING, "strip",  1,0,  "Strip leading and trailing whitespace from string."},
+	{FUNC_CLASS_STRING, "collapse_whitespace",  1,0,  "Strip repeated whitespace from string."},
+	{FUNC_CLASS_STRING, "clean_whitespace",  1,0,  "Same as collapse_whitespace and strip."},
 
 	{FUNC_CLASS_MATH, "abs",      1,0, "Absolute value."},
 	{FUNC_CLASS_MATH, "acos",     1,0, "Inverse trigonometric cosine."},
@@ -295,11 +303,16 @@ static function_lookup_t FUNCTION_LOOKUP_TABLE[] = {
 		"Formats floating-point seconds as in\nfsec2dhms(500000.25) = \"5d18h53m20.250000s\""},
 	{FUNC_CLASS_TIME, "fsec2hms",  1,0,
 		"Formats floating-point seconds as in\nfsec2hms(5000.25) = \"01:23:20.250000\""},
+
 	{FUNC_CLASS_TIME, "gmt2sec",   1,0, "Parses GMT timestamp as integer seconds since\nthe epoch."},
+	{FUNC_CLASS_TIME, "localtime2sec", 1,0, "Parses local timestamp as integer seconds since\n"
+		"the epoch. Consults $TZ environment variable."},
+
 	{FUNC_CLASS_TIME, "hms2fsec",  1,0,
 		"Recovers floating-point seconds as in\nhms2fsec(\"01:23:20.250000\") = 5000.250000"},
 	{FUNC_CLASS_TIME, "hms2sec",   1,0, "Recovers integer seconds as in\nhms2sec(\"01:23:20\") = 5000"},
 	{FUNC_CLASS_TIME, "sec2dhms",  1,0, "Formats integer seconds as in sec2dhms(500000)\n= \"5d18h53m20s\""},
+
 	{FUNC_CLASS_TIME, "sec2gmt",   1,0,
 		"Formats seconds since epoch (integer part)\n"
 		"as GMT timestamp, e.g. sec2gmt(1440768801.7) = \"2015-08-28T13:33:21Z\".\n"
@@ -312,6 +325,19 @@ static function_lookup_t FUNCTION_LOOKUP_TABLE[] = {
 		"Formats seconds since epoch (integer part)\n"
 		"as GMT timestamp with year-month-date, e.g. sec2gmtdate(1440768801.7) = \"2015-08-28\".\n"
 		"Leaves non-numbers as-is."},
+
+	{FUNC_CLASS_TIME, "sec2localtime",   1,0, "Formats seconds since epoch (integer part)\n"
+		"as local timestamp, e.g. sec2localtime(1440768801.7) = \"2015-08-28T13:33:21Z\".\n"
+		"Consults $TZ environment variable. Leaves non-numbers as-is."},
+	{FUNC_CLASS_TIME, "sec2localtime",   2,0,
+		"Formats seconds since epoch as local timestamp with n\n"
+		"decimal places for seconds, e.g. sec2localtime(1440768801.7,1) = \"2015-08-28T13:33:21.7Z\".\n"
+		"Consults $TZ environment variable. Leaves non-numbers as-is."},
+	{FUNC_CLASS_TIME, "sec2localdate", 1,0,
+		"Formats seconds since epoch (integer part)\n"
+		"as local timestamp with year-month-date, e.g. sec2localdate(1440768801.7) = \"2015-08-28\".\n"
+		"Consults $TZ environment variable. Leaves non-numbers as-is."},
+
 	{FUNC_CLASS_TIME, "sec2hms",   1,0,
 		"Formats integer seconds as in\n"
 		"sec2hms(5000) = \"01:23:20\""},
@@ -320,12 +346,18 @@ static function_lookup_t FUNCTION_LOOKUP_TABLE[] = {
 		"strftime(1440768801.7,\"%Y-%m-%dT%H:%M:%SZ\") = \"2015-08-28T13:33:21Z\", and\n"
 		"strftime(1440768801.7,\"%Y-%m-%dT%H:%M:%3SZ\") = \"2015-08-28T13:33:21.700Z\".\n"
 		"Format strings are as in the C library (please see \"man strftime\" on your system),\n"
-		"with the Miller-specific addition of \"%1S\" through \"%9S\" which format the seocnds\n"
-		"with 1 through 9 decimal places, respectively. (\"%S\" uses no decimal places.)"},
+		"with the Miller-specific addition of \"%1S\" through \"%9S\" which format the seconds\n"
+		"with 1 through 9 decimal places, respectively. (\"%S\" uses no decimal places.)\n"
+		"See also strftime_local."},
+	{FUNC_CLASS_TIME, "strftime_local",  2,0,
+		"Like strftime but consults the $TZ environment variable to get local time zone."},
 	{FUNC_CLASS_TIME, "strptime",  2,0,
 		"Parses timestamp as floating-point seconds since the epoch,\n"
 		"e.g. strptime(\"2015-08-28T13:33:21Z\",\"%Y-%m-%dT%H:%M:%SZ\") = 1440768801.000000,\n"
-		"and  strptime(\"2015-08-28T13:33:21.345Z\",\"%Y-%m-%dT%H:%M:%SZ\") = 1440768801.345000."},
+		"and  strptime(\"2015-08-28T13:33:21.345Z\",\"%Y-%m-%dT%H:%M:%SZ\") = 1440768801.345000.\n"
+		"See also strptime_local."},
+	{FUNC_CLASS_TIME, "strptime_local",  2,0,
+		"Like strptime, but consults $TZ environment variable to find and use local timezone."},
 	{FUNC_CLASS_TIME, "systime",   0,0,
 		"Floating-point seconds since the epoch,\n"
 		"e.g. 1440768801.748936." },
@@ -468,7 +500,7 @@ static void fmgr_check_arity_with_report(fmgr_t* pfmgr, char* function_name,
 		// More flexibly, I'd have a list of arities supported by each
 		// function. But this is overkill: there are unary and binary minus and sec2gmt,
 		// and everything else has a single arity.
-		if (streq(function_name, "-") || streq(function_name, "sec2gmt")) {
+		if (streq(function_name, "-") || streq(function_name, "sec2gmt") || streq(function_name, "sec2localtime")) {
 			fprintf(stderr, "%s: Function named \"%s\" takes one argument or two; got %d.\n",
 				MLR_GLOBALS.bargv0, function_name, user_provided_arity);
 		} else if (*pvariadic) {
@@ -933,11 +965,16 @@ static rval_evaluator_t* construct_builtin_function_callsite_evaluator(
 		mlr_dsl_ast_node_t* parg2_node = pnode->pchildren->phead->pnext->pvvalue;
 		int type2 = parg2_node->type;
 
-		if ((streq(function_name, "=~") || streq(function_name, "!=~")) && type2 == MD_AST_NODE_TYPE_STRING_LITERAL) {
+		int is_regexy =
+			streq(function_name, "=~") ||
+			streq(function_name, "!=~") ||
+			streq(function_name, "regextract");
+
+		if (is_regexy && type2 == MD_AST_NODE_TYPE_STRING_LITERAL) {
 			rval_evaluator_t* parg1 = rval_evaluator_alloc_from_ast(parg1_node, pfmgr, type_inferencing, context_flags);
 			pevaluator = fmgr_alloc_evaluator_from_binary_regex_arg2_func_name(function_name,
 				parg1, parg2_node->text, FALSE);
-		} else if ((streq(function_name, "=~") || streq(function_name, "!=~")) && type2 == MD_AST_NODE_TYPE_REGEXI) {
+		} else if (is_regexy && type2 == MD_AST_NODE_TYPE_REGEXI) {
 			rval_evaluator_t* parg1 = rval_evaluator_alloc_from_ast(parg1_node, pfmgr, type_inferencing, context_flags);
 			pevaluator = fmgr_alloc_evaluator_from_binary_regex_arg2_func_name(function_name, parg1, parg2_node->text,
 				TYPE_INFER_STRING_FLOAT_INT);
@@ -956,14 +993,19 @@ static rval_evaluator_t* construct_builtin_function_callsite_evaluator(
 		mlr_dsl_ast_node_t* parg3_node = pnode->pchildren->phead->pnext->pnext->pvvalue;
 		int type2 = parg2_node->type;
 
-		if ((streq(function_name, "sub") || streq(function_name, "gsub")) && type2 == MD_AST_NODE_TYPE_STRING_LITERAL) {
+		int is_regexy =
+			streq(function_name, "sub") ||
+			streq(function_name, "gsub") ||
+			streq(function_name, "regextract_or_else");
+
+		if (is_regexy && type2 == MD_AST_NODE_TYPE_STRING_LITERAL) {
 			// sub/gsub-regex special case:
 			rval_evaluator_t* parg1 = rval_evaluator_alloc_from_ast(parg1_node, pfmgr, type_inferencing, context_flags);
 			rval_evaluator_t* parg3 = rval_evaluator_alloc_from_ast(parg3_node, pfmgr, type_inferencing, context_flags);
 			pevaluator = fmgr_alloc_evaluator_from_ternary_regex_arg2_func_name(function_name, parg1, parg2_node->text,
 				FALSE, parg3);
 
-		} else if ((streq(function_name, "sub") || streq(function_name, "gsub")) && type2 == MD_AST_NODE_TYPE_REGEXI) {
+		} else if (is_regexy && type2 == MD_AST_NODE_TYPE_REGEXI) {
 			// sub/gsub-regex special case:
 			rval_evaluator_t* parg1 = rval_evaluator_alloc_from_ast(parg1_node, pfmgr, type_inferencing, context_flags);
 			rval_evaluator_t* parg3 = rval_evaluator_alloc_from_ast(parg3_node, pfmgr, type_inferencing, context_flags);
@@ -1133,6 +1175,7 @@ static rval_evaluator_t* fmgr_alloc_evaluator_from_unary_func_name(char* fnnm, r
 	} else if (streq(fnnm, "fsec2dhms"))       { return rval_evaluator_alloc_from_s_f_func(s_f_fsec2dhms_func,   parg1);
 	} else if (streq(fnnm, "fsec2hms"))        { return rval_evaluator_alloc_from_s_f_func(s_f_fsec2hms_func,    parg1);
 	} else if (streq(fnnm, "gmt2sec"))         { return rval_evaluator_alloc_from_i_s_func(i_s_gmt2sec_func,     parg1);
+	} else if (streq(fnnm, "localtime2sec"))   { return rval_evaluator_alloc_from_i_s_func(i_s_localtime2sec_func, parg1);
 	} else if (streq(fnnm, "hexfmt"))          { return rval_evaluator_alloc_from_x_x_func(s_x_hexfmt_func,      parg1);
 	} else if (streq(fnnm, "hms2fsec"))        { return rval_evaluator_alloc_from_f_s_func(f_s_hms2fsec_func,    parg1);
 	} else if (streq(fnnm, "hms2sec"))         { return rval_evaluator_alloc_from_f_s_func(i_s_hms2sec_func,     parg1);
@@ -1146,6 +1189,8 @@ static rval_evaluator_t* fmgr_alloc_evaluator_from_unary_func_name(char* fnnm, r
 	} else if (streq(fnnm, "sec2dhms"))        { return rval_evaluator_alloc_from_s_i_func(s_i_sec2dhms_func,    parg1);
 	} else if (streq(fnnm, "sec2gmt"))         { return rval_evaluator_alloc_from_x_x_func(s_x_sec2gmt_func,     parg1);
 	} else if (streq(fnnm, "sec2gmtdate"))     { return rval_evaluator_alloc_from_x_x_func(s_x_sec2gmtdate_func, parg1);
+	} else if (streq(fnnm, "sec2localtime"))   { return rval_evaluator_alloc_from_x_x_func(s_x_sec2localtime_func, parg1);
+	} else if (streq(fnnm, "sec2localdate"))   { return rval_evaluator_alloc_from_x_x_func(s_x_sec2localdate_func, parg1);
 	} else if (streq(fnnm, "sec2hms"))         { return rval_evaluator_alloc_from_s_i_func(s_i_sec2hms_func,     parg1);
 	} else if (streq(fnnm, "sgn"))             { return rval_evaluator_alloc_from_x_x_func(x_x_sgn_func,         parg1);
 	} else if (streq(fnnm, "sin"))             { return rval_evaluator_alloc_from_f_f_func(f_f_sin_func,         parg1);
@@ -1157,6 +1202,11 @@ static rval_evaluator_t* fmgr_alloc_evaluator_from_unary_func_name(char* fnnm, r
 	} else if (streq(fnnm, "tanh"))            { return rval_evaluator_alloc_from_f_f_func(f_f_tanh_func,        parg1);
 	} else if (streq(fnnm, "tolower"))         { return rval_evaluator_alloc_from_s_s_func(s_s_tolower_func,     parg1);
 	} else if (streq(fnnm, "toupper"))         { return rval_evaluator_alloc_from_s_s_func(s_s_toupper_func,     parg1);
+	} else if (streq(fnnm, "lstrip"))          { return rval_evaluator_alloc_from_s_s_func(s_s_lstrip_func,      parg1);
+	} else if (streq(fnnm, "rstrip"))          { return rval_evaluator_alloc_from_s_s_func(s_s_rstrip_func,      parg1);
+	} else if (streq(fnnm, "strip"))           { return rval_evaluator_alloc_from_s_s_func(s_s_strip_func,       parg1);
+	} else if (streq(fnnm, "collapse_whitespace")) { return rval_evaluator_alloc_from_s_s_func(s_s_collapse_whitespace_func, parg1);
+	} else if (streq(fnnm, "clean_whitespace")) { return rval_evaluator_alloc_from_s_s_func(s_s_clean_whitespace_func, parg1);
 	} else if (streq(fnnm, "~"))               { return rval_evaluator_alloc_from_i_i_func(i_i_bitwise_not_func, parg1);
 
 	} else return NULL;
@@ -1171,6 +1221,8 @@ static rval_evaluator_t* fmgr_alloc_evaluator_from_binary_func_name(char* fnnm,
 	} else if (streq(fnnm, "^^"))   { return rval_evaluator_alloc_from_b_bb_xor_func(parg1, parg2);
 	} else if (streq(fnnm, "=~"))   { return rval_evaluator_alloc_from_x_ssc_func(
 		matches_no_precomp_func, parg1, parg2);
+	} else if (streq(fnnm, "regextract"))   { return rval_evaluator_alloc_from_x_ss_func(
+		regextract_no_precomp_func, parg1, parg2);
 	} else if (streq(fnnm, "!=~"))  { return rval_evaluator_alloc_from_x_ssc_func(does_not_match_no_precomp_func, parg1, parg2);
 	} else if (streq(fnnm, "=="))   { return rval_evaluator_alloc_from_x_xx_func(eq_op_func,             parg1, parg2);
 	} else if (streq(fnnm, "!="))   { return rval_evaluator_alloc_from_x_xx_func(ne_op_func,             parg1, parg2);
@@ -1200,13 +1252,16 @@ static rval_evaluator_t* fmgr_alloc_evaluator_from_binary_func_name(char* fnnm,
 	} else if (streq(fnnm, "fmtnum")) { return rval_evaluator_alloc_from_s_xs_func(s_xs_fmtnum_func,     parg1, parg2);
 	} else if (streq(fnnm, "urandint")) { return rval_evaluator_alloc_from_i_ii_func(i_ii_urandint_func, parg1, parg2);
 	} else if (streq(fnnm, "sec2gmt"))  { return rval_evaluator_alloc_from_x_xi_func(s_xi_sec2gmt_func,  parg1, parg2);
+	} else if (streq(fnnm, "sec2localtime")) { return rval_evaluator_alloc_from_x_xi_func(s_xi_sec2localtime_func, parg1, parg2);
 	} else if (streq(fnnm, "&"))    { return rval_evaluator_alloc_from_x_xx_func(x_xx_band_func,         parg1, parg2);
 	} else if (streq(fnnm, "|"))    { return rval_evaluator_alloc_from_x_xx_func(x_xx_bor_func,          parg1, parg2);
 	} else if (streq(fnnm, "^"))    { return rval_evaluator_alloc_from_x_xx_func(x_xx_bxor_func,         parg1, parg2);
 	} else if (streq(fnnm, "<<"))   { return rval_evaluator_alloc_from_i_ii_func(i_ii_bitwise_lsh_func,  parg1, parg2);
 	} else if (streq(fnnm, ">>"))   { return rval_evaluator_alloc_from_i_ii_func(i_ii_bitwise_rsh_func,  parg1, parg2);
 	} else if (streq(fnnm, "strftime")) { return rval_evaluator_alloc_from_x_ns_func(s_ns_strftime_func, parg1, parg2);
+	} else if (streq(fnnm, "strftime_local")) { return rval_evaluator_alloc_from_x_ns_func(s_ns_strftime_local_func, parg1, parg2);
 	} else if (streq(fnnm, "strptime")) { return rval_evaluator_alloc_from_x_ss_func(i_ss_strptime_func, parg1, parg2);
+	} else if (streq(fnnm, "strptime_local")) { return rval_evaluator_alloc_from_x_ss_func(i_ss_strptime_local_func, parg1, parg2);
 	} else  { return NULL; }
 }
 
@@ -1217,6 +1272,8 @@ static rval_evaluator_t* fmgr_alloc_evaluator_from_binary_regex_arg2_func_name(c
 		return rval_evaluator_alloc_from_x_sr_func(matches_precomp_func,        parg1, regex_string, ignore_case);
 	} else if (streq(fnnm, "!=~")) {
 		return rval_evaluator_alloc_from_x_sr_func(does_not_match_precomp_func, parg1, regex_string, ignore_case);
+	} else if (streq(fnnm, "regextract")) {
+		return rval_evaluator_alloc_from_x_se_func(regextract_precomp_func, parg1, regex_string, ignore_case);
 	} else  { return NULL; }
 }
 
@@ -1228,6 +1285,10 @@ static rval_evaluator_t* fmgr_alloc_evaluator_from_ternary_func_name(char* fnnm,
 		return rval_evaluator_alloc_from_s_sss_func(sub_no_precomp_func,  parg1, parg2, parg3);
 	} else if (streq(fnnm, "gsub")) {
 		return rval_evaluator_alloc_from_s_sss_func(gsub_no_precomp_func, parg1, parg2, parg3);
+	} else if (streq(fnnm, "ssub")) {
+		return rval_evaluator_alloc_from_s_sss_func(s_sss_ssub_func,      parg1, parg2, parg3);
+	} else if (streq(fnnm, "regextract_or_else")) {
+		return rval_evaluator_alloc_from_s_sss_func(regextract_or_else_no_precomp_func, parg1, parg2, parg3);
 	} else if (streq(fnnm, "logifit")) {
 		return rval_evaluator_alloc_from_f_fff_func(f_fff_logifit_func,   parg1, parg2, parg3);
 	} else if (streq(fnnm, "madd")) {
@@ -1252,6 +1313,8 @@ static rval_evaluator_t* fmgr_alloc_evaluator_from_ternary_regex_arg2_func_name(
 		return rval_evaluator_alloc_from_x_srs_func(sub_precomp_func,  parg1, regex_string, ignore_case, parg3);
 	} else if (streq(fnnm, "gsub"))  {
 		return rval_evaluator_alloc_from_x_srs_func(gsub_precomp_func, parg1, regex_string, ignore_case, parg3);
+	} else if (streq(fnnm, "regextract_or_else"))  {
+		return rval_evaluator_alloc_from_x_ses_func(regextract_or_else_precomp_func, parg1, regex_string, ignore_case, parg3);
 	} else  { return NULL; }
 }
 
