@@ -192,6 +192,100 @@ mv_t gsub_precomp_func(mv_t* pval1, regex_t* pregex, string_builder_t* psb, mv_t
 	return mv_from_string(output, free_flags);
 }
 
+// ----------------------------------------------------------------
+mv_t regextract_no_precomp_func(mv_t* pval1, mv_t* pval2) {
+	regex_t regex;
+	mv_t rv = regextract_precomp_func(pval1, regcomp_or_die(&regex, pval2->u.strv, 0));
+	regfree(&regex);
+	mv_free(pval2);
+	return rv;
+}
+
+// ----------------------------------------------------------------
+mv_t regextract_precomp_func(mv_t* pval1, regex_t* pregex) {
+	char* input  = pval1->u.strv;
+	char* output = regextract(input, pregex);
+
+	mv_free(pval1);
+	if (output == NULL) {
+		return mv_absent();
+	} else {
+		return mv_from_string_with_free(output);
+	}
+}
+
+// ----------------------------------------------------------------
+mv_t regextract_or_else_no_precomp_func(mv_t* pval1, mv_t* pval2, mv_t* pval3) {
+	regex_t regex;
+	mv_t rv = regextract_or_else_precomp_func(pval1, regcomp_or_die(&regex, pval2->u.strv, 0), pval3);
+	regfree(&regex);
+	mv_free(pval2);
+	return rv;
+}
+
+// ----------------------------------------------------------------
+mv_t regextract_or_else_precomp_func(mv_t* pval1, regex_t* pregex, mv_t* pval3) {
+	char* input  = pval1->u.strv;
+	char* default_value  = pval3->u.strv;
+	char* output = regextract_or_else(input, pregex, default_value);
+
+	mv_free(pval1);
+	mv_free(pval3);
+	return mv_from_string_with_free(output);
+}
+
+// ----------------------------------------------------------------
+// String-substitution with no regexes or special characters.
+// It is assumed that all inputs have already been checked to be strings.
+mv_t s_sss_ssub_func(mv_t* pmvinput, mv_t* pmvold, mv_t* pmvnew) {
+	char* pinput = pmvinput->u.strv;
+	char* pold = pmvold->u.strv;
+	char* pnew = pmvnew->u.strv;
+
+	char* pmatch = strstr(pinput, pold);
+
+	if (pmatch == NULL) {
+		mv_free(pmvold);
+		mv_free(pmvnew);
+		return *pmvinput;
+	} else {
+		// Example:
+		// input: aaaaOOObbbbb
+		// old:   OOO
+		// new:   NNNNN
+		// Output length: strlen(aaaa) + strlen(NNNNN) + strlen(bbbbb)
+
+		// Compute lengths
+		int input_length = strlen(pinput);
+		int old_length = strlen(pold);
+		int new_length = strlen(pnew);
+		int output_length = input_length - old_length + new_length + 1;
+		int pre_length = pmatch - pinput; // the "aaaa" part
+		int post_length = input_length - pre_length - old_length; // the "bbbbb" part
+
+		// Allocate output
+		char* poutput = mlr_malloc_or_die(output_length);
+		char* p = poutput;
+
+		// Populate output
+		strncpy(p, pinput, pre_length);
+		p += pre_length;
+
+		strcpy(p, pnew);
+		p += new_length;
+
+		strcpy(p, &pinput[pre_length + old_length]);
+		p += post_length;
+
+		*p = 0;
+
+		mv_free(pmvinput);
+		mv_free(pmvold);
+		mv_free(pmvnew);
+		return mv_from_string(poutput, FREE_ENTRY_VALUE);
+	}
+}
+
 // ----------------------------------------------------------------
 // https://en.wikipedia.org/wiki/Hamming_weight
 
@@ -293,6 +387,19 @@ mv_t i_iii_modexp_func(mv_t* pval1, mv_t* pval2, mv_t* pval3) {
 	return mv_from_int(c);
 }
 
+// ----------------------------------------------------------------
+mv_t i_s_strlen_func(mv_t* pval1) {
+	mv_t rv = mv_from_int(strlen_for_utf8_display(pval1->u.strv));
+	mv_free(pval1);
+	return rv;
+}
+
+mv_t s_x_typeof_func(mv_t* pval1) {
+	mv_t rv = mv_from_string(mt_describe_type(pval1->type), NO_FREE);
+	mv_free(pval1);
+	return rv;
+}
+
 // ----------------------------------------------------------------
 mv_t s_s_tolower_func(mv_t* pval1) {
 	char* string = mlr_strdup_or_die(pval1->u.strv);
@@ -314,21 +421,72 @@ mv_t s_s_toupper_func(mv_t* pval1) {
 	return mv_from_string_with_free(string);
 }
 
-mv_t i_s_strlen_func(mv_t* pval1) {
-	mv_t rv = mv_from_int(strlen_for_utf8_display(pval1->u.strv));
-	mv_free(pval1);
-	return rv;
+// ----------------------------------------------------------------
+mv_t s_s_lstrip_func(mv_t* pval1) {
+	if (!isspace(pval1->u.strv[0])) {
+		return *pval1;
+	} else {
+		char* p = pval1->u.strv;
+		while (isspace(*p)) {
+			p++;
+		}
+		return mv_from_string(mlr_strdup_or_die(p), FREE_ENTRY_VALUE);
+	}
 }
 
-mv_t s_x_typeof_func(mv_t* pval1) {
-	mv_t rv = mv_from_string(mt_describe_type(pval1->type), NO_FREE);
+mv_t s_s_rstrip_func(mv_t* pval1) {
+	char* start = pval1->u.strv;
+	int oldlen = strlen(start);
+	char* last_non_space = &start[oldlen-1];
+	while ((start <= last_non_space) && isspace(*last_non_space))
+		last_non_space--;
+	if (last_non_space < start) {
+		mv_free(pval1);
+		return mv_empty();
+	} else {
+		int newlen = (last_non_space - start) + 1;
+		char* retval = mlr_malloc_or_die(newlen + 1);
+		memcpy(retval, start, newlen);
+		retval[newlen] = 0;
+		mv_free(pval1);
+		return mv_from_string(retval, FREE_ENTRY_VALUE);
+	}
+}
+
+mv_t s_s_strip_func(mv_t* pval1) {
+	mv_t temp = s_s_rstrip_func(pval1);
+	return s_s_lstrip_func(&temp);
+}
+
+mv_t s_s_collapse_whitespace_func(mv_t* pval1) {
+	int len = strlen(pval1->u.strv);
+	char* retval = mlr_malloc_or_die(len+1);
+	char* pdst = retval;
+	int last_was_space = FALSE;
+	for (char* psrc = pval1->u.strv; *psrc; psrc++) {
+		int current_is_space = isspace(*psrc);
+		if (last_was_space && current_is_space) {
+		} else {
+			*pdst = *psrc;
+			pdst++;
+		}
+		last_was_space = current_is_space;
+	}
+	*pdst = 0;
 	mv_free(pval1);
-	return rv;
+	return mv_from_string(retval, FREE_ENTRY_VALUE);
+}
+
+mv_t s_s_clean_whitespace_func(mv_t* pval1) {
+	mv_t temp = s_s_collapse_whitespace_func(pval1);
+	return s_s_strip_func(&temp);
 }
 
 // ----------------------------------------------------------------
 // Precondition: psec is either int or float.
-mv_t time_string_from_seconds(mv_t* psec, char* format) {
+mv_t time_string_from_seconds(mv_t* psec, char* format,
+	timezone_handling_t timezone_handling)
+{
 	double seconds_since_the_epoch = 0.0;
 	if (psec->type == MT_FLOAT) {
 		if (isinf(psec->u.fltv) || isnan(psec->u.fltv)) {
@@ -339,13 +497,16 @@ mv_t time_string_from_seconds(mv_t* psec, char* format) {
 		seconds_since_the_epoch = psec->u.intv;
 	}
 
-	char* string = mlr_alloc_time_string_from_seconds(seconds_since_the_epoch, format);
+	char* string = mlr_alloc_time_string_from_seconds(seconds_since_the_epoch, format,
+		timezone_handling);
 
 	return mv_from_string_with_free(string);
 }
 
 // ----------------------------------------------------------------
-static mv_t sec2gmt_s_n(mv_t* pa) { return time_string_from_seconds(pa, ISO8601_TIME_FORMAT); }
+static mv_t sec2gmt_s_n(mv_t* pa) {
+	return time_string_from_seconds(pa, ISO8601_TIME_FORMAT, TIMEZONE_HANDLING_GMT);
+}
 
 static mv_unary_func_t* sec2gmt_dispositions[MT_DIM] = {
 	/*ERROR*/  _err1,
@@ -361,15 +522,15 @@ mv_t s_x_sec2gmt_func(mv_t* pval1) { return (sec2gmt_dispositions[pval1->type])(
 // Precondition: val2 is already asserted int
 static mv_t sec2gmt_s_ni(mv_t* pa, mv_t* pb) {
 	switch (pb->u.intv) {
-	case 1: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_1); break;
-	case 2: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_2); break;
-	case 3: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_3); break;
-	case 4: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_4); break;
-	case 5: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_5); break;
-	case 6: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_6); break;
-	case 7: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_7); break;
-	case 8: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_8); break;
-	case 9: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_9); break;
+	case 1: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_1, TIMEZONE_HANDLING_GMT); break;
+	case 2: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_2, TIMEZONE_HANDLING_GMT); break;
+	case 3: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_3, TIMEZONE_HANDLING_GMT); break;
+	case 4: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_4, TIMEZONE_HANDLING_GMT); break;
+	case 5: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_5, TIMEZONE_HANDLING_GMT); break;
+	case 6: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_6, TIMEZONE_HANDLING_GMT); break;
+	case 7: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_7, TIMEZONE_HANDLING_GMT); break;
+	case 8: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_8, TIMEZONE_HANDLING_GMT); break;
+	case 9: return time_string_from_seconds(pa, ISO8601_TIME_FORMAT_9, TIMEZONE_HANDLING_GMT); break;
 	default: return mv_error();
 	}
 }
@@ -386,7 +547,9 @@ static mv_binary_func_t* sec2gmtn_dispositions[MT_DIM] = {
 mv_t s_xi_sec2gmt_func(mv_t* pval1, mv_t* pval2) { return (sec2gmtn_dispositions[pval1->type])(pval1, pval2); }
 
 // ----------------------------------------------------------------
-static mv_t sec2gmtdate_s_n(mv_t* pa) { return time_string_from_seconds(pa, ISO8601_DATE_FORMAT); }
+static mv_t sec2gmtdate_s_n(mv_t* pa) {
+	return time_string_from_seconds(pa, ISO8601_DATE_FORMAT, TIMEZONE_HANDLING_GMT);
+}
 
 static mv_unary_func_t* sec2gmtdate_dispositions[MT_DIM] = {
 	/*ERROR*/  _err1,
@@ -400,30 +563,113 @@ static mv_unary_func_t* sec2gmtdate_dispositions[MT_DIM] = {
 
 mv_t s_x_sec2gmtdate_func(mv_t* pval1) { return (sec2gmtdate_dispositions[pval1->type])(pval1); }
 
+// ----------------------------------------------------------------
+static mv_t sec2localtime_s_n(mv_t* pa) {
+	return time_string_from_seconds(pa, ISO8601_LOCAL_TIME_FORMAT, TIMEZONE_HANDLING_LOCAL);
+}
+
+static mv_unary_func_t* sec2localtime_dispositions[MT_DIM] = {
+	/*ERROR*/  _err1,
+	/*ABSENT*/ _a1,
+	/*EMPTY*/  _emt1,
+	/*STRING*/ _0,
+	/*INT*/    sec2localtime_s_n,
+	/*FLOAT*/  sec2localtime_s_n,
+	/*BOOL*/   _0,
+};
+mv_t s_x_sec2localtime_func(mv_t* pval1) { return (sec2localtime_dispositions[pval1->type])(pval1); }
+
+// Precondition: val2 is already asserted int
+static mv_t sec2localtime_s_ni(mv_t* pa, mv_t* pb) {
+	switch (pb->u.intv) {
+	case 1: return time_string_from_seconds(pa, ISO8601_LOCAL_TIME_FORMAT_1, TIMEZONE_HANDLING_LOCAL); break;
+	case 2: return time_string_from_seconds(pa, ISO8601_LOCAL_TIME_FORMAT_2, TIMEZONE_HANDLING_LOCAL); break;
+	case 3: return time_string_from_seconds(pa, ISO8601_LOCAL_TIME_FORMAT_3, TIMEZONE_HANDLING_LOCAL); break;
+	case 4: return time_string_from_seconds(pa, ISO8601_LOCAL_TIME_FORMAT_4, TIMEZONE_HANDLING_LOCAL); break;
+	case 5: return time_string_from_seconds(pa, ISO8601_LOCAL_TIME_FORMAT_5, TIMEZONE_HANDLING_LOCAL); break;
+	case 6: return time_string_from_seconds(pa, ISO8601_LOCAL_TIME_FORMAT_6, TIMEZONE_HANDLING_LOCAL); break;
+	case 7: return time_string_from_seconds(pa, ISO8601_LOCAL_TIME_FORMAT_7, TIMEZONE_HANDLING_LOCAL); break;
+	case 8: return time_string_from_seconds(pa, ISO8601_LOCAL_TIME_FORMAT_8, TIMEZONE_HANDLING_LOCAL); break;
+	case 9: return time_string_from_seconds(pa, ISO8601_LOCAL_TIME_FORMAT_9, TIMEZONE_HANDLING_LOCAL); break;
+	default: return mv_error();
+	}
+}
+
+static mv_binary_func_t* sec2localn_dispositions[MT_DIM] = {
+	/*ERROR*/  _err,
+	/*ABSENT*/ _a,
+	/*EMPTY*/  _emt,
+	/*STRING*/ _1,
+	/*INT*/    sec2localtime_s_ni,
+	/*FLOAT*/  sec2localtime_s_ni,
+	/*BOOL*/   _1,
+};
+mv_t s_xi_sec2localtime_func(mv_t* pval1, mv_t* pval2) { return (sec2localn_dispositions[pval1->type])(pval1, pval2); }
+
+// ----------------------------------------------------------------
+static mv_t sec2localdate_s_n(mv_t* pa) {
+	return time_string_from_seconds(pa, ISO8601_DATE_FORMAT, TIMEZONE_HANDLING_LOCAL);
+}
+
+static mv_unary_func_t* sec2localdate_dispositions[MT_DIM] = {
+	/*ERROR*/  _err1,
+	/*ABSENT*/ _a1,
+	/*EMPTY*/  _emt1,
+	/*STRING*/ _0,
+	/*INT*/    sec2localdate_s_n,
+	/*FLOAT*/  sec2localdate_s_n,
+	/*BOOL*/   _0,
+};
+
+mv_t s_x_sec2localdate_func(mv_t* pval1) { return (sec2localdate_dispositions[pval1->type])(pval1); }
+
+
 // ----------------------------------------------------------------
 mv_t s_ns_strftime_func(mv_t* pval1, mv_t* pval2) {
-	mv_t rv = time_string_from_seconds(pval1, pval2->u.strv);
+	mv_t rv = time_string_from_seconds(pval1, pval2->u.strv, TIMEZONE_HANDLING_GMT);
 	mv_free(pval2);
 	return rv;
 }
 
 // ----------------------------------------------------------------
-static mv_t seconds_from_time_string(char* string, char* format) {
+mv_t s_ns_strftime_local_func(mv_t* pval1, mv_t* pval2) {
+	mv_t rv = time_string_from_seconds(pval1, pval2->u.strv, TIMEZONE_HANDLING_LOCAL);
+	mv_free(pval2);
+	return rv;
+}
+
+// ----------------------------------------------------------------
+static mv_t seconds_from_time_string(char* string, char* format,
+	timezone_handling_t timezone_handling)
+{
 	if (*string == '\0') {
 		return mv_empty();
 	} else {
-		return mv_from_float(mlr_seconds_from_time_string(string, format));
+		return mv_from_float(mlr_seconds_from_time_string(string, format, timezone_handling));
 	}
 }
 
 mv_t i_s_gmt2sec_func(mv_t* pval1) {
-	mv_t rv = seconds_from_time_string(pval1->u.strv, ISO8601_TIME_FORMAT);
+	mv_t rv = seconds_from_time_string(pval1->u.strv, ISO8601_TIME_FORMAT, TIMEZONE_HANDLING_GMT);
+	mv_free(pval1);
+	return rv;
+}
+
+mv_t i_s_localtime2sec_func(mv_t* pval1) {
+	mv_t rv = seconds_from_time_string(pval1->u.strv, ISO8601_LOCAL_TIME_FORMAT, TIMEZONE_HANDLING_LOCAL);
 	mv_free(pval1);
 	return rv;
 }
 
 mv_t i_ss_strptime_func(mv_t* pval1, mv_t* pval2) {
-	mv_t rv = seconds_from_time_string(pval1->u.strv, pval2->u.strv);
+	mv_t rv = seconds_from_time_string(pval1->u.strv, pval2->u.strv, TIMEZONE_HANDLING_GMT);
+	mv_free(pval1);
+	mv_free(pval2);
+	return rv;
+}
+
+mv_t i_ss_strptime_local_func(mv_t* pval1, mv_t* pval2) {
+	mv_t rv = seconds_from_time_string(pval1->u.strv, pval2->u.strv, TIMEZONE_HANDLING_LOCAL);
 	mv_free(pval1);
 	mv_free(pval2);
 	return rv;
