@@ -22,7 +22,7 @@ static mapper_t* mapper_cut_parse_cli(int* pargi, int argc, char** argv,
 	cli_reader_opts_t* _, cli_writer_opts_t* __);
 static mapper_t* mapper_cut_alloc(ap_state_t* pargp, slls_t* pfield_name_list,
 	int do_arg_order, int do_complement, int do_regexes);
-static void      mapper_cut_free(mapper_t* pmapper);
+static void      mapper_cut_free(mapper_t* pmapper, context_t* _);
 static sllv_t*   mapper_cut_process_no_regexes(lrec_t* pinrec, context_t* pctx, void* pvstate);
 static sllv_t*   mapper_cut_process_with_regexes(lrec_t* pinrec, context_t* pctx, void* pvstate);
 
@@ -31,6 +31,7 @@ mapper_setup_t mapper_cut_setup = {
 	.verb = "cut",
 	.pusage_func = mapper_cut_usage,
 	.pparse_func = mapper_cut_parse_cli,
+	.ignores_input = FALSE,
 };
 
 // ----------------------------------------------------------------
@@ -111,18 +112,18 @@ static mapper_t* mapper_cut_alloc(ap_state_t* pargp, slls_t* pfield_name_list,
 			regcomp_or_die_quoted(&pstate->regexes[i], pe->value, REG_NOSUB);
 		}
 		slls_free(pfield_name_list);
-		pmapper->pprocess_func     = mapper_cut_process_with_regexes;
+		pmapper->pprocess_func = mapper_cut_process_with_regexes;
 	}
-	pstate->do_arg_order   = do_arg_order;
-	pstate->do_complement  = do_complement;
+	pstate->do_arg_order  = do_arg_order;
+	pstate->do_complement = do_complement;
 
-	pmapper->pvstate       = (void*)pstate;
-	pmapper->pfree_func    = mapper_cut_free;
+	pmapper->pvstate      = (void*)pstate;
+	pmapper->pfree_func   = mapper_cut_free;
 
 	return pmapper;
 }
 
-static void mapper_cut_free(mapper_t* pmapper) {
+static void mapper_cut_free(mapper_t* pmapper, context_t* _) {
 	mapper_cut_state_t* pstate = pmapper->pvstate;
 	slls_free(pstate->pfield_name_list);
 	hss_free(pstate->pfield_name_set);
