@@ -11,14 +11,15 @@ static void      mapper_tac_usage(FILE* o, char* argv0, char* verb);
 static mapper_t* mapper_tac_parse_cli(int* pargi, int argc, char** argv,
 	cli_reader_opts_t* _, cli_writer_opts_t* __);
 static mapper_t* mapper_tac_alloc();
-static void      mapper_tac_free(mapper_t* pmapper);
+static void      mapper_tac_free(mapper_t* pmapper, context_t* _);
 static sllv_t*   mapper_tac_process(lrec_t* pinrec, context_t* pctx, void* pvstate);
 
 // ----------------------------------------------------------------
 mapper_setup_t mapper_tac_setup = {
 	.verb = "tac",
 	.pusage_func = mapper_tac_usage,
-	.pparse_func = mapper_tac_parse_cli
+	.pparse_func = mapper_tac_parse_cli,
+	.ignores_input = FALSE,
 };
 
 // ----------------------------------------------------------------
@@ -53,7 +54,7 @@ static mapper_t* mapper_tac_alloc() {
 	return pmapper;
 }
 
-static void mapper_tac_free(mapper_t* pmapper) {
+static void mapper_tac_free(mapper_t* pmapper, context_t* _) {
 	mapper_tac_state_t* pstate = pmapper->pvstate;
 	// Free the container
 	sllv_free(pstate->records);
