@@ -4,14 +4,17 @@
 #include "containers/slls.h"
 #include "mapping/mapper.h"
 
+extern mapper_setup_t mapper_altkv_setup;
 extern mapper_setup_t mapper_bar_setup;
 extern mapper_setup_t mapper_bootstrap_setup;
 extern mapper_setup_t mapper_cat_setup;
 extern mapper_setup_t mapper_check_setup;
+extern mapper_setup_t mapper_clean_whitespace_setup;
 extern mapper_setup_t mapper_count_distinct_setup;
 extern mapper_setup_t mapper_count_similar_setup;
 extern mapper_setup_t mapper_cut_setup;
 extern mapper_setup_t mapper_decimate_setup;
+extern mapper_setup_t mapper_fill_down_setup;
 extern mapper_setup_t mapper_filter_setup;
 extern mapper_setup_t mapper_fraction_setup;
 extern mapper_setup_t mapper_grep_setup;
