@@ -5,12 +5,13 @@
 #include "containers/mixutil.h"
 #include "output/lrec_writers.h"
 
-typedef void       quoted_output_func_t(FILE* fp, char* string, char* ors, char* ofs, int orslen, int ofslen, char quote_flags);
-static  void      quote_all_output_func(FILE* fp, char* string, char* ors, char* ofs, int orslen, int ofslen, char quote_flags);
-static  void     quote_none_output_func(FILE* fp, char* string, char* ors, char* ofs, int orslen, int ofslen, char quote_flags);
-static  void  quote_minimal_output_func(FILE* fp, char* string, char* ors, char* ofs, int orslen, int ofslen, char quote_flags);
-static  void  quote_numeric_output_func(FILE* fp, char* string, char* ors, char* ofs, int orslen, int ofslen, char quote_flags);
-static  void quote_original_output_func(FILE* fp, char* string, char* ors, char* ofs, int orslen, int ofslen, char quote_flags);
+typedef void       quoted_output_func_t(FILE* fp,char*s,char*ors,char*ofs, int orslen,int ofslen, char quote_flags);
+static  void      quote_all_output_func(FILE* fp,char*s,char*ors,char*ofs, int orslen,int ofslen, char quote_flags);
+static  void     quote_none_output_func(FILE* fp,char*s,char*ors,char*ofs, int orslen,int ofslen, char quote_flags);
+static  void  quote_minimal_output_func(FILE* fp,char*s,char*ors,char*ofs, int orslen,int ofslen, char quote_flags);
+static  void  quote_minimal_auto_output_func(FILE* fp,char*s,char*ors,char*ofs, int orslen,int ofslen, char qf);
+static  void  quote_numeric_output_func(FILE* fp,char*s,char*ors,char*ofs, int orslen,int ofslen, char quote_flags);
+static  void quote_original_output_func(FILE* fp,char*s,char*ors,char*ofs, int orslen,int ofslen, char quote_flags);
 static void quote_string(FILE* fp, char* string);
 
 typedef struct _lrec_writer_csv_state_t {
@@ -26,8 +27,10 @@ typedef struct _lrec_writer_csv_state_t {
 } lrec_writer_csv_state_t;
 
 // ----------------------------------------------------------------
-static void lrec_writer_csv_process(void* pvstate, FILE* output_stream, lrec_t* prec);
-static void lrec_writer_csv_free(lrec_writer_t* pwriter);
+static void lrec_writer_csv_process(void* pvstate, FILE* output_stream, lrec_t* prec, char* ors);
+static void lrec_writer_csv_process_auto_ors(void* pvstate, FILE* output_stream, lrec_t* prec, context_t* pctx);
+static void lrec_writer_csv_process_nonauto_ors(void* pvstate, FILE* output_stream, lrec_t* prec, context_t* pctx);
+static void lrec_writer_csv_free(lrec_writer_t* pwriter, context_t* pctx);
 
 // ----------------------------------------------------------------
 lrec_writer_t* lrec_writer_csv_alloc(char* ors, char* ofs, quoting_t oquoting, int headerless_csv_output) {
@@ -48,22 +51,27 @@ lrec_writer_t* lrec_writer_csv_alloc(char* ors, char* ofs, quoting_t oquoting, i
 	case QUOTE_NUMERIC:  pstate->pquoted_output_func = quote_numeric_output_func;  break;
 	case QUOTE_ORIGINAL: pstate->pquoted_output_func = quote_original_output_func; break;
 	default:
-		fprintf(stderr, "%s: internal coding error: output-quoting style 0x%x unrecognized.\n",
-			MLR_GLOBALS.bargv0, oquoting);
-		exit(1);
+		MLR_INTERNAL_CODING_ERROR();
 	}
 
 	pstate->num_header_lines_output = 0LL;
 	pstate->plast_header_output     = NULL;
 
-	plrec_writer->pvstate       = (void*)pstate;
-	plrec_writer->pprocess_func = lrec_writer_csv_process;
-	plrec_writer->pfree_func    = lrec_writer_csv_free;
+	plrec_writer->pvstate = (void*)pstate;
+	if (streq(ors, "auto")) {
+		plrec_writer->pprocess_func = lrec_writer_csv_process_auto_ors;
+		if (oquoting == QUOTE_MINIMAL) {
+			pstate->pquoted_output_func = quote_minimal_auto_output_func;
+		}
+	} else {
+		plrec_writer->pprocess_func = lrec_writer_csv_process_nonauto_ors;
+	}
+	plrec_writer->pfree_func = lrec_writer_csv_free;
 
 	return plrec_writer;
 }
 
-static void lrec_writer_csv_free(lrec_writer_t* pwriter) {
+static void lrec_writer_csv_free(lrec_writer_t* pwriter, context_t* pctx) {
 	lrec_writer_csv_state_t* pstate = pwriter->pvstate;
 	slls_free(pstate->plast_header_output);
 	free(pstate);
@@ -71,12 +79,21 @@ static void lrec_writer_csv_free(lrec_writer_t* pwriter) {
 }
 
 // ----------------------------------------------------------------
-static void lrec_writer_csv_process(void* pvstate, FILE* output_stream, lrec_t* prec) {
+static void lrec_writer_csv_process_auto_ors(void* pvstate, FILE* output_stream, lrec_t* prec, context_t* pctx) {
+	lrec_writer_csv_process(pvstate, output_stream, prec, pctx->auto_line_term);
+}
+
+static void lrec_writer_csv_process_nonauto_ors(void* pvstate, FILE* output_stream, lrec_t* prec, context_t* pctx) {
+	lrec_writer_csv_state_t* pstate = pvstate;
+	lrec_writer_csv_process(pvstate, output_stream, prec, pstate->ors);
+}
+
+static void lrec_writer_csv_process(void* pvstate, FILE* output_stream, lrec_t* prec, char* ors) {
 	if (prec == NULL)
 		return;
 	lrec_writer_csv_state_t* pstate = pvstate;
-	char *ors = pstate->ors;
 	char *ofs = pstate->ofs;
+	int orslen = strlen(ors);
 
 	if (pstate->plast_header_output != NULL) {
 		if (!lrec_keys_equal_list(prec, pstate->plast_header_output)) {
@@ -94,7 +111,7 @@ static void lrec_writer_csv_process(void* pvstate, FILE* output_stream, lrec_t*
 				if (nf > 0)
 					fputs(ofs, output_stream);
 				pstate->pquoted_output_func(output_stream, pe->key, pstate->ors, pstate->ofs,
-					pstate->orslen, pstate->ofslen, 0);
+					orslen, pstate->ofslen, 0);
 				nf++;
 			}
 			fputs(ors, output_stream);
@@ -108,7 +125,7 @@ static void lrec_writer_csv_process(void* pvstate, FILE* output_stream, lrec_t*
 		if (nf > 0)
 			fputs(ofs, output_stream);
 		pstate->pquoted_output_func(output_stream, pe->value, pstate->ors, pstate->ofs,
-			pstate->orslen, pstate->ofslen, pe->quote_flags);
+			orslen, pstate->ofslen, pe->quote_flags);
 		nf++;
 	}
 	fputs(ors, output_stream);
@@ -119,21 +136,31 @@ static void lrec_writer_csv_process(void* pvstate, FILE* output_stream, lrec_t*
 }
 
 // ----------------------------------------------------------------
-static void quote_all_output_func(FILE* fp, char* string, char* ors, char* ofs, int orslen, int ofslen, char quote_flags) {
+static void quote_all_output_func(FILE* fp, char* string, char* ors, char* ofs, int orslen, int ofslen,
+	char quote_flags)
+{
 	quote_string(fp, string);
 }
 
-static void quote_none_output_func(FILE* fp, char* string, char* ors, char* ofs, int orslen, int ofslen, char quote_flags) {
+static void quote_none_output_func(FILE* fp, char* string, char* ors, char* ofs, int orslen, int ofslen,
+	char quote_flags)
+{
 	fputs(string, fp);
 }
 
-static void quote_minimal_output_func(FILE* fp, char* string, char* ors, char* ofs, int orslen, int ofslen, char quote_flags) {
+static void quote_minimal_output_func(FILE* fp, char* string, char* ors, char* ofs, int orslen, int ofslen,
+	char quote_flags)
+{
 	int output_quotes = FALSE;
 	for (char* p = string; *p; p++) {
 		if (streqn(p, ors, orslen) || streqn(p, ofs, ofslen)) {
 			output_quotes = TRUE;
 			break;
 		}
+		if (*p == '"') {
+			output_quotes = TRUE;
+			break;
+		}
 	}
 	if (output_quotes) {
 		quote_string(fp, string);
@@ -142,7 +169,30 @@ static void quote_minimal_output_func(FILE* fp, char* string, char* ors, char* o
 	}
 }
 
-static void quote_numeric_output_func(FILE* fp, char* string, char* ors, char* ofs, int orslen, int ofslen, char quote_flags) {
+static void quote_minimal_auto_output_func(FILE* fp, char* string, char* _, char* ofs, int __, int ofslen,
+	char quote_flags)
+{
+	int output_quotes = FALSE;
+	for (char* p = string; *p; p++) {
+		if (streqn(p, "\n", 1) || streqn(p, "\r\n", 2) || streqn(p, ofs, ofslen)) {
+			output_quotes = TRUE;
+			break;
+		}
+		if (*p == '"') {
+			output_quotes = TRUE;
+			break;
+		}
+	}
+	if (output_quotes) {
+		quote_string(fp, string);
+	} else {
+		fputs(string, fp);
+	}
+}
+
+static void quote_numeric_output_func(FILE* fp, char* string, char* ors, char* ofs, int orslen, int ofslen,
+	char quote_flags)
+{
 	double temp;
 	if (mlr_try_float_from_string(string, &temp)) {
 		quote_string(fp, string);
@@ -151,7 +201,9 @@ static void quote_numeric_output_func(FILE* fp, char* string, char* ors, char* o
 	}
 }
 
-static void quote_original_output_func(FILE* fp, char* string, char* ors, char* ofs, int orslen, int ofslen, char quote_flags) {
+static void quote_original_output_func(FILE* fp, char* string, char* ors, char* ofs, int orslen, int ofslen,
+	char quote_flags)
+{
 	if (quote_flags & FIELD_QUOTED_ON_INPUT) {
 		quote_string(fp, string);
 	} else {
